/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.platform.osgi;

import java.io.*;
import java.util.Date;
import java.util.logging.Level;
import java.util.logging.Handler;
import java.util.logging.LogRecord;

import org.osgi.service.log.*;

/**
 * @author BarryAtkins
 */

public class OSGiLogHandler extends Handler
{
    private static LogService _logService = null;
    
    private static LogReaderService _logReaderService = null;
    
    protected OSGiLogListener _listener = null;
    
    public OSGiLogHandler(String logfile) throws IOException
    {
        _listener = new OSGiLogListener(logfile);
        
        if (_logReaderService != null)
            _logReaderService.addLogListener(_listener);
    }
    
    public static void setLogService(LogService logService)
    {
        _logService = logService;
    }
    
    public static void setLogReaderService(LogReaderService logReaderService)
    {
        _logReaderService = logReaderService;
    }
    
    public void publish(LogRecord record)
    {
        if (_logService != null)
            _logService.log(record.getLevel().intValue(), record.getMessage());
        
        else
            _listener.log(record.getLevel(), record.getMessage());
    }
    
    public void close()
    {
        if (_logReaderService != null)
            _logReaderService.removeLogListener(_listener);
        
        _listener.close();
    }
    
    public void flush()
    {
        
    }
}
