/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.platform.osgi;

import java.io.*;
import java.util.Date;
import java.util.logging.Level;

import org.osgi.service.log.LogEntry;
import org.osgi.service.log.LogListener;

/**
 * 
 * @author Barry Atkins
 *
 */

public class OSGiLogListener implements LogListener
{
    private FileWriter _writer = null;
    
    public OSGiLogListener(String fileName)
        throws IOException
    {
        _writer = new FileWriter(fileName);
    }
    
    public void close()
    {
        try
        {
            _writer.flush();
            _writer.close();
        }
        
        catch (IOException error)
        {
            error.printStackTrace();
        }
    }
    
    public void log(Level level, String message)
    {
        log(message);
    }

    public void log(String message)
    {
        try
        {
            Date now = new Date();
            
            _writer.write("[ ");
            _writer.write(now.toString());
            _writer.write(" ] ");
            _writer.write(message);
            _writer.write('\n');
        }
        
        catch (IOException error)
        {
            error.printStackTrace();
        }
    }
    
    public void logged(LogEntry entry)
    {
        log(entry.getMessage());
    }
}
