/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.platform.osgi.mini.internal;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import org.apache.muse.core.Environment;
import org.apache.muse.core.platform.mini.MiniEnvironment;
import org.apache.muse.core.platform.mini.MiniIsolationLayer;
import org.apache.muse.core.platform.osgi.util.OSGiReflectUtilHelper;
import org.apache.muse.util.ReflectUtils;

public class OSGiMiniIsolationLayer extends MiniIsolationLayer  {

	protected boolean initializing = false;
	protected boolean initialized = false;

	public OSGiMiniIsolationLayer(HttpServletRequest initialRequest, ServletContext initialContext){
    	super(initialRequest,initialContext);
    }
	
    protected Environment createEnvironment()
    {
        return new OSGiMiniEnvironment(getInitialRequest(), getInitialContext());
    }
	

	/**
	 * performs initialzation of the IsolationLayer, and installs the
	 * <code>OSGiReflectUtilHelper</code> singleton as the <code>ReflectUtils</code>
	 * helper.
	 * 
	 * @see ReflectUtils
	 * @see OSGiReflectUtilHelper
	 */
	public void initialize() {

		if(initializing) return;

		ClassLoader prev = Thread.currentThread().getContextClassLoader();
		try {
			initializing = true;
			ReflectUtils.setHelper(OSGiReflectUtilHelper.getDefault());
			Thread.currentThread().setContextClassLoader(
					OSGiMiniIsolationLayer.class.getClassLoader());
			super.initialize();
			initialized = true;
		} catch (RuntimeException e) {
			e.printStackTrace();
			throw e;
		} finally {
			Thread.currentThread().setContextClassLoader(prev);
		}
	}

}
