/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.platform.mini;

import java.io.File;
import java.net.URI;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import org.apache.muse.core.AbstractEnvironment;
import org.apache.muse.util.FileUtils;
import org.apache.muse.ws.addressing.EndpointReference;

/**
 * 
 * @author Dan Jemiolo (danj)
 *
 */

public class MiniEnvironment extends AbstractEnvironment
{
    private static final String _DIRECTORY_PATH = "/WEB-INF/classes";
    
    private File _realDirectory = null;
    
    public MiniEnvironment(HttpServletRequest httpRequest, ServletContext servletContext)
    {
        String realDirectoryPath = servletContext.getRealPath(_DIRECTORY_PATH);
        
        if (realDirectoryPath == null)
            _realDirectory = FileUtils.CURRENT_DIR;
        
        else
            _realDirectory = new File(realDirectoryPath);
        
        setDefaultURI(httpRequest.getRequestURL().toString());
    }
    
    public EndpointReference getDeploymentEPR()
    {
        String defaultString = getDefaultURI();
        URI defaultURI = URI.create(defaultString);
        return new EndpointReference(defaultURI);
    }

    public File getRealDirectory()
    {
        return _realDirectory;
    }
}
