/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package java.util.logging;

import java.io.FileWriter;
import java.io.IOException;
import java.util.Date;

/**
 * 
 * @author Barry Atkins
 *
 */

public class FileHandler extends Handler
{
    private FileWriter _writer = null;
    
    public FileHandler(String fileName)
        throws IOException
    {
        _writer = new FileWriter(fileName);
    }
    
    public void close()
    {
        try
        {
            _writer.flush();
            _writer.close();
        }
        
        catch (IOException error)
        {
            error.printStackTrace();
        }
    }

    public void publish(LogRecord record)
    {
        try
        {
            Date time = new Date(record.getMillis());
            
            _writer.write("[ ");
            _writer.write(time.toString());
            _writer.write(" ] ");
            _writer.write(record.getMessage());
            _writer.write('\n');
        }
        
        catch (IOException error)
        {
            error.printStackTrace();
        }
    }
}
