/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package java.util.logging;

import java.util.HashMap;
import java.util.Map;

/**
 * 
 * @author Barry Atkins
 * 
 */

public class Level
{
    public static final Level OFF = new Level("OFF", 0);
    
    public static final Level SEVERE = new Level("SEVERE", 1);
    
    public static final Level WARNING = new Level("WARNING", 2);
    
    public static final Level INFO = new Level("INFO", 3);
    
    public static final Level CONFIG = new Level("CONFIG", 4);
    
    public static final Level FINE = new Level("FINE", 5);
    
    public static final Level FINER = new Level("FINER", 6);
    
    public static final Level FINEST = new Level("FINEST", 7);
    
    public static final Level ALL = new Level("ALL", 8);
    
    private static final Map _LEVELS_BY_NAME = new HashMap();
    
    static
    {
        _LEVELS_BY_NAME.put(OFF.getName(), OFF);
        _LEVELS_BY_NAME.put(SEVERE.getName(), SEVERE);
        _LEVELS_BY_NAME.put(WARNING.getName(), WARNING);
        _LEVELS_BY_NAME.put(INFO.getName(), INFO);
        _LEVELS_BY_NAME.put(CONFIG.getName(), CONFIG);
        _LEVELS_BY_NAME.put(FINE.getName(), FINE);
        _LEVELS_BY_NAME.put(FINER.getName(), FINER);
        _LEVELS_BY_NAME.put(FINEST.getName(), FINEST);
        _LEVELS_BY_NAME.put(ALL.getName(), ALL);
    }
    
    private String _name = null;
    
    private int _value;
    
    private Level(String name, int value)
    {
        _name = name;
        _value = value;
    }
    
    public String getName()
    {
        return _name;
    }
    
    public int intValue()
    {
        return _value;
    }
    
    public static Level parse(String name)
    {
        Level level = (Level)_LEVELS_BY_NAME.get(name);
        
        if (level == null)
            throw new IllegalArgumentException("Invalid logging level: " + name);
        
        return level;
    }
    
    public String toString()
    {
        return getName();
    }
}
