/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.dm.muws.impl;

import java.util.ArrayList;
import java.util.List;

import javax.xml.namespace.QName;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.ws.dm.muws.ManageabilityCharacteristics;

/**
 *
 * SimpleManageabilityCharacteristics is Muse's default implementation of 
 * the WSDM ManageabilityCharacteristics capability.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SimpleManageabilityCharacteristics 
    extends AbstractManageabilityCapability implements ManageabilityCharacteristics
{
    private static Messages _MESSAGES = 
        MessagesFactory.get(SimpleManageabilityCharacteristics.class);
    
    private List _capabilities = new ArrayList();

    public void addManageabilityCapability(String capabilityURI)
    {
        if (hasManageabilityCapability(capabilityURI))
        {
            Object[] filler = { getResource().getContextPath(), capabilityURI, _capabilities };
            throw new RuntimeException(_MESSAGES.get("DuplicateCapability", filler));
        }
        
        _capabilities.add(capabilityURI);
    }
    
    public String[] getManageabilityCapability()
    {
        String[] array = new String[_capabilities.size()];
        return (String[])_capabilities.toArray(array);
    }
    
    public QName[] getPropertyNames()
    {
        return PROPERTIES;
    }
    
    public boolean hasManageabilityCapability(String capabilityURI)
    {
        return _capabilities.contains(capabilityURI);
    }
}
