/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.notification.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.notification.WsnConstants;
import org.apache.muse.ws.notification.topics.WstConstants;

/**
 *
 * GetCurrentMessage is a serializer/deserializer for the WS-Notification 
 * GetCurrentMessage operation's request content.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class GetCurrentMessage implements XmlSerializable
{
    private static Messages _MESSAGES = MessagesFactory.get(GetCurrentMessage.class);
    
    private QName _topicPath = null;
    
    public GetCurrentMessage(Element xml)
    {
        _topicPath = XmlUtils.getQNameFromChild(xml, WsnConstants.TOPIC_QNAME);
    }
    
    public GetCurrentMessage(QName topicPath)
    {
        _topicPath = topicPath;
    }
    
    protected String getDialect(String name)
    {
        return name.indexOf('/') >= 0 ? WstConstants.CONCRETE_TOPIC_URI : WstConstants.SIMPLE_TOPIC_URI;
    }
    
    public QName getTopicPath()
    {
        return _topicPath;
    }
    
    public Element toXML()
    {
        return toXML(XmlUtils.EMPTY_DOC);
    }
    
    public Element toXML(Document doc)
    {
        if (doc == null)
            throw new NullPointerException(_MESSAGES.get("NullDocument"));
        
        Element root = XmlUtils.createElement(doc, WsnConstants.GET_CURRENT_QNAME);
        Element topic = XmlUtils.createElement(doc, WsnConstants.TOPIC_QNAME, getTopicPath());
                
        String dialect = getDialect(_topicPath.getLocalPart());
        topic.setAttribute(WsnConstants.DIALECT, dialect);
        
        root.appendChild(topic);
        return root;
    }
}
