/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.notification.impl;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.notification.NotificationMessage;
import org.apache.muse.ws.notification.WsnConstants;

/**
 *
 * GetCurrentMessageResponse is a serializer/deserializer for the WS-Notification 
 * GetCurrentMessage operation's response content.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class GetCurrentMessageResponse implements XmlSerializable
{
    private static Messages _MESSAGES = MessagesFactory.get(GetCurrentMessageResponse.class);
    
    private NotificationMessage _message = null;
    
    public GetCurrentMessageResponse(Element xml) 
        throws SoapFault
    {
        Element messageXML = XmlUtils.getFirstElement(xml);
        
        if (messageXML != null)
            _message = new SimpleNotificationMessage(messageXML);
    }
    
    public GetCurrentMessageResponse(NotificationMessage message)
    {
        _message = message;
    }
    
    public NotificationMessage getMessage()
    {
        return _message;
    }
    
    public Element toXML()
    {
        return toXML(XmlUtils.EMPTY_DOC);
    }
    
    public Element toXML(Document doc)
    {
        if (doc == null)
            throw new NullPointerException(_MESSAGES.get("NullDocument"));
        
        Element root = XmlUtils.createElement(doc, WsnConstants.GET_CURRENT_RESPONSE_QNAME);
        
        if (_message != null)
        {
            Element messageXML = _message.toXML(doc);
            root.appendChild(messageXML);
        }
        
        return root;
    }
}
