/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.notification.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.notification.Filter;
import org.apache.muse.ws.notification.WsnConstants;
import org.apache.muse.ws.notification.topics.WstConstants;
import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class TopicFilterHandler implements FilterFactoryHandler
{
    public boolean accepts(QName filterName, String filterDialect)
    {
        boolean rightName = filterName.equals(WsnConstants.TOPIC_EXPRESSION_QNAME);
        boolean rightDialect = filterDialect.equals(WstConstants.CONCRETE_TOPIC_URI);
        return rightName && rightDialect;
    }
    
    public Filter newInstance(Element filterXML)
        throws BaseFault
    {
        String dialect = filterXML.getAttribute(WsnConstants.DIALECT);
        QName topicName = XmlUtils.getQName(filterXML);
        return new TopicFilter(topicName, dialect);
    }
}
