/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.ws.addressing.osgi;


import org.apache.muse.util.osgi.AbstractResourceManagementImplementation;
import org.osgi.framework.Bundle;
import org.osgi.framework.ServiceFactory;
import org.osgi.framework.ServiceRegistration;

/**
 * WSASOAPContribution is an implementation of the <code>ResourceManagementImplementation</code>
 * service interface for the WSA SOAP bundle.
 * 
 * @see ResourceManagementImplementation
 * @author Joel Hawkins (joelh)
 *
 */
public class WSASOAPContribution extends AbstractResourceManagementImplementation implements ServiceFactory {
	private static final String IMPLEMENTATION_NAME = "wsa-soap";
	
	private static final String[] RESOURCE_SPECS = { 
	"SOAP-Envelope-1_2.xsd",
	"WS-Addressing-2005_08.xsd",
	"XML-Namespace-1998.xsd"	
	};
	
	
	public WSASOAPContribution(Bundle bundle){
		super(bundle);
		this.implementationName = IMPLEMENTATION_NAME;
		this.resourceSpecNames = RESOURCE_SPECS;
	}
	

	public Object getService(Bundle bundle, ServiceRegistration registration) {
		return this;
	}

	public void ungetService(Bundle bundle, ServiceRegistration registration, Object service) {
	}
	
}
